#
# spec file for package NetworkManager-strongswan
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NetworkManager-strongswan
Version:        1.6.0
Release:        1.1
Summary:        NetworkManager VPN support for strongSwan
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://www.strongswan.org/
Source0:        https://download.strongswan.org/NetworkManager/%{name}-%{version}.tar.bz2
Source1:        https://download.strongswan.org/NetworkManager/%{name}-%{version}.tar.bz2.sig
Source2:        %{name}.keyring
Source99:       README
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libnma) >= 1.1.0
BuildRequires:  pkgconfig(libnma-gtk4)
BuildRequires:  pkgconfig(libsecret-1)

Requires:       NetworkManager >= 1.1.0
Requires:       strongswan-nm >= 5.8.3
Supplements:    (NetworkManager and strongswan-nm)
ExcludeArch:    s390 s390x

%description
NetworkManager-strongswan provides VPN support to NetworkManager for
strongSwan.

%package -n NetworkManager-applet-strongswan
Summary:        NetworkManager VPN support for strongSwan
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Provides:       %{name}-frontend
Provides:       %{name}-gnome = %{version}
Obsoletes:      %{name}-gnome
Supplements:    (%{name} and NetworkManager-applet)

%description -n NetworkManager-applet-strongswan
NetworkManager-strongswan provides VPN support to NetworkManager for
strongSwan.

%lang_package

%prep
%autosetup -p1
cp %{SOURCE99} README.SUSE

%build
%configure \
	--disable-static \
	--without-libnm-glib \
	--with-charon=%{_libexecdir}/ipsec/charon-nm \
	--with-nm_libexecdir=%{_libexecdir} \
	--disable-more-warnings \
	--with-gtk4
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%doc README.SUSE
%{_vpnservicedir}/nm-strongswan-service.name
%{_libdir}/NetworkManager/libnm-vpn-plugin-strongswan.so

%files -n NetworkManager-applet-strongswan
%{_libexecdir}/nm-strongswan-auth-dialog
%{_libdir}/NetworkManager/libnm-gtk4-vpn-plugin-strongswan-editor.so
%{_libdir}/NetworkManager/libnm-vpn-plugin-strongswan-editor.so
%{_datadir}/metainfo/NetworkManager-strongswan.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Thu Nov  2 2023 Callum Farmer <gmbr3@opensuse.org>
- Rename gnome subpackage to NetworkManager-applet-strongswan
  to more accurately reflect its usage
- Add missing supplements:
  - NM and strongswan-nm
  - NMA subpackage: Main package and NMA
* Thu Sep  7 2023 Jens K. <karatekhd@opensuse.org>
- Update to version 1.6.0
  + Support for GTK4
  + Removed libnm-glib compatibility
- Add pkgconfig(gtk4) because the new version requires this
- Add pkgconfig(libnma-gtk4) because the new version requires this
* Mon Jun  7 2021 Predrag Ivanović <predivan@mts.rs>
- Update to version 1.5.2
  + Reduce height of config dialog by moving options/proposals to tabs
  + Migrated appdata to metainfo (renamed and moved the file)
- Update to version 1.5.1
  + Fixes password entry for private keys
* Mon May  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.5.0:
  + EAP-TLS authentication
  + Certificate source (file, agent, smartcard) is selectable
    independently
  + Add support to configure local and remote identities
  + Support configuring a custom server port
  + Show hint regarding password storage policy
  + Replaced the term "gateway" with "server"
  + Fixes build issues due to use of deprecated GLib
    macros/functions
  + Updated Glade file to GTK 3.2
* Fri May  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
- Pass --with-nm-libexecdir=%%{_libexecdir} to configure to behave
  the same as all the other NM-VPN plugins. This results in
  nm-strongswan-auth-dialog moving from
  %%{_libexecdir}/NetworkManager to %%{_libexecdir}, but considering
  all the other auth-dialog helpers are there as well it is
  perfectly welcome.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Oct  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.5:
  + Enables the IPv6 tab in the connection dialog.
- Use modern macros.
* Mon Jun 11 2018 bjorn.lie@gmail.com
- Fix packaging error in previous sub, README was moved from
  source1 tag to source3, move to tag source99 to avoid similar
  error in the future.
* Wed May 23 2018 kbabioch@suse.com
- Use OpenPGP signature provided upstream
- Added NetworkManager-strongswan.keyring, which contains the key
  from the author.
* Wed May  9 2018 bjorn.lie@gmail.com
- Update to version 1.4.4:
  + Fixed paths when building without libnm-glib.
  + Fixed proposal tooltips.
  + Updated translations.
* Tue Apr 17 2018 bjorn.lie@gmail.com
- Pass --without-libnm-glib, no longer build deprecated libnm-glib
  support, following this, drop pkgconfig(NetworkManager),
  pkgconfig(libnm-glib), pkgconfig(libnm-glib-vpn),
  pkgconfig(libnm-gtk) and pkgconfig(libnm-util) BuildRequires.
- Add pkgconfig(libnm) BuildRequires.
- Add explicit --with-charon=%%%%{_libexecdir}/ipsec/charon-nm to
  configure.
- Drop unneeded NetworkManager-gnome Requires from gnome
  sub-package, it is no longer of use for us.
* Wed Mar  7 2018 bjorn.lie@gmail.com
- Update to version 1.4.3:
  + Add option to disable libnm-glib compatibility.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Sep  7 2017 zaitor@opensuse.org
- Update to version 1.4.2:
  + Add support to configure IKE/ESP proposals.
  + Explicitly prevent PIN from getting stored.
* Fri Oct 28 2016 zaitor@opensuse.org
- Update to version 1.4.1:
  + Fixed several build issues.
* Fri Sep  9 2016 zaitor@opensuse.org
- Update to version 1.4.0:
  + Updated to NetworkManager 1.2.
- Changes from version 1.3.2:
  + GUI fix.
  + Update to libsecret.
  + D-Bus policy moved to charon-nm.
- Modify BuildRequires following upstreams changes:
  + Drop: pkgconfig(gnome-keyring-1), pkgconfig(gtk+-2.0),
    pkgconfig(dbus-glib-1) and pkgconfig(libgnomeui-2.0).
  + Add pkgconfig, pkgconfig(libnm-gtk), pkgconfig(libnma),
    pkgconfig(gtk+-3.0) and pkgconfig(libsecret-1).
- Drop nm-strongswan-service-conf.patch,
  nm-strongswan-fix-config.patch and nm-strongswan-UI-fixup.patch.
- Drop libtool BuildRequires and autoreconf call, we no longer
  carry any patches.
* Tue Sep  8 2015 dimstar@opensuse.org
- Add nm-strongswan-fix-config.patch: Fix path to NM plugins in
  config files (boo#944769).
- Add nm-strongswan-UI-fixup.patch: Fix broken UI (boo#944769).
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
* Wed Jun 10 2015 dimstar@opensuse.org
- Drop the sed hack to fix bnc#824079: since verson 1.3.1, the
  charon binary to be found is already called charon-nm by
  upstream (boo#934129).
- Clean out conditions for legacy openSUSE versions: we will always
  require strongswan > 5 as a consequence (which is correct, as
  that's when charon-nm was introduced).
* Fri Apr 25 2014 dimstar@opensuse.org
- Update to version 1.3.1:
  + Add PSK support.
  + Updated translations.
* Mon Mar 31 2014 dimstar@opensuse.org
- Pass --disable-more-warnings to configure: deal with deprecations
  in libraries (like libgnome-keyring).
* Mon Jun 10 2013 i@marguerite.su
- fix bnc#824079: "program" in nm-strongswan-service.name points
  to a wrong binary
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Thu Sep 29 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: NetworkManager-devel, libglade2-devel,
    libgnomeui-devel, libgudev-1_0-devel.
  + New ones: NetworkManager, dbus-glib-1, gnome-keyring-1,
    gtk+-2.0, libgnomeui-2.0, libnm-glib,libnm-glib-vpn,
    libnm-util.
- Remove unneeded update-desktop-files BuildRequires.
* Wed Sep 28 2011 dimstar@opensuse.org
- Update to version 1.3.0:
  + Updated to NetworkManager 0.9
* Mon Dec  6 2010 vuntz@opensuse.org
- Update to version 1.2.0:
  + Added Smartcard support
- Remove unneeded dependencies: NetworkManager-gnome,
  perl-XML-Parser.
- Make sure to install README from the source package (as
  README.SUSE).
* Fri Nov 19 2010 binli@opensuse.org
- Add the 1.1.2's package.
